==> butternut-0.4.3.tgz: package/src/program/types/VariableDeclaration.js <==
import Node from '../Node.js';
import extractNames from '../extractNames.js';

export default class VariableDeclaration extends Node {
	attachScope ( scope ) {
		this.declarations.forEach( declarator => {
			declarator.attachScope( scope );
		});

		scope.functionScope.varDeclarationNodes.push( this );
	}

	initialise ( scope ) {
		let _scope = scope;
		if ( this.kind === 'var' ) while ( _scope.isBlockScope ) _scope = _scope.parent;

		if ( _scope.parent ) {
			// noop — we wait for this declaration to be activated
			// TODO what about `var a = b()` — need to init the init
		} else {
			super.initialise( scope );
		}
	}

	minify ( code ) {
		const declarations = this.declarations.filter( d => !d.skip );

		let allDupes = declarations.every( declarator => {
			return extractNames( declarator.id ).every( identifier => {
				return identifier.isDuplicate;
			});
		});

		let c = allDupes ? this.start : this.start + this.kind.length + ( this.declarations[0].id.type === 'Identifier' ? 1 : 0 );

		for ( let i = 0; i < declarations.length; i += 1 ) {
			const declarator = declarations[i];
			if ( declarator.skip ) continue;

			if ( declarator.start > c ) code.overwrite( c, declarator.start, i ? ',' : '' );
			c = declarator.end;
		}

		// we may have been asked to declare some additional vars, if they were
		// declared inside blocks that have been removed
		if ( this.rideAlongs ) code.appendLeft( c, `,` + this.rideAlongs.join( ',' ) );

		if ( this.end > c + 1 ) code.remove( c, this.end - 1 ); // TODO semi-less declarations

		declarations.forEach( declarator => declarator.minify( code ) );
	}
}

==> butternut-0.4.4.tgz: package/src/program/types/VariableDeclaration.js <==
import Node from '../Node.js';
import extractNames from '../extractNames.js';

export default class VariableDeclaration extends Node {
	attachScope ( scope ) {
		this.declarations.forEach( declarator => {
			declarator.attachScope( scope );
		});

		scope.functionScope.varDeclarationNodes.push( this );
	}

	initialise ( scope ) {
		let _scope = scope;
		if ( this.kind === 'var' ) while ( _scope.isBlockScope ) _scope = _scope.parent;

		if ( _scope.parent ) {
			// noop — we wait for this declaration to be activated
			// TODO what about `var a = b()` — need to init the init
		} else {
			super.initialise( scope );
		}
	}

	minify ( code ) {
		const declarations = this.declarations.filter( d => !d.skip );

		let allDupes = declarations.every( declarator => {
			const names = extractNames( declarator.id );
			return names.length > 0 && names.every( identifier => {
				return identifier.isDuplicate;
			});
		});

		let c = allDupes ? this.start : this.start + this.kind.length + ( this.declarations[0].id.type === 'Identifier' ? 1 : 0 );

		for ( let i = 0; i < declarations.length; i += 1 ) {
			const declarator = declarations[i];
			if ( declarator.skip ) continue;

			if ( declarator.start > c ) code.overwrite( c, declarator.start, i ? ',' : '' );
			c = declarator.end;
		}

		// we may have been asked to declare some additional vars, if they were
		// declared inside blocks that have been removed
		if ( this.rideAlongs ) code.appendLeft( c, `,` + this.rideAlongs.join( ',' ) );

		if ( this.end > c + 1 ) code.remove( c, this.end - 1 ); // TODO semi-less declarations

		declarations.forEach( declarator => declarator.minify( code ) );
	}
}
